pub trait Object:
Clone
+ Debug
+ PartialEq
+ Eq
+ Send
+ Sync { }Expand description
A basic trait we expect algebraic data structures to implement.
Types implementing this trait need to support:
T.clone(),format!("{:?}", &T)&T == &T,&T != &T.
In other words, being clonable, and comparable for equality.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".