F

Struct F 

pub struct F(/* private fields */);
An element of the Goldilocks field.

Implementations

Source

impl F

pub const ROOT_OF_UNITY: Self

An element of order 2^32.

This is specifically chosen such that ROOT_OF_UNITY^(2^26) = 8.

That enables optimizations when doing NTTs, and things like that.

pub const NOT_ROOT_OF_UNITY: Self

An element guaranteed not to be any power of Self::ROOT_OF_UNITY.

pub const NOT_ROOT_OF_UNITY_INV: Self

The inverse of Self::NOT_ROOT_OF_UNITY.

pub fn inv(self) -> Self

Return the multiplicative inverse of a field element.

Self::zero will return Self::zero.

pub fn stream_from_u64s( inner: impl Iterator<Item = u64>, ) -> impl Iterator<Item = Self>

Convert a stream of u64s into a stream of field elements.

pub fn stream_to_u64s( inner: impl Iterator<Item = Self>, ) -> impl Iterator<Item = u64>

Convert a stream produced by F::stream_from_u64s back to the original stream.

This may produce a single extra 0 element.

pub const fn bits_to_elements(bits: usize) -> usize

How many elements are used to encode a given number of bits?

This is based on what F::stream_from_u64s does.

pub const fn to_le_bytes(&self) -> [u8; 8]

Convert this element to little-endian bytes.