Module ntt

Module ntt 

Structs

EvaluationVector
The result of evaluating a vector of polynomials over all points in an interpolation domain.
Matrix
Represents a matrix of field elements, of arbitrary dimensions
PolynomialVector
VanishingPoints
Used to keep track of the points at which a polynomial needs to vanish.

Functions

lagrange_coefficients
Compute Lagrange coefficients for interpolating a polynomial at 0 from evaluations at roots of unity.