pub struct EvaluationVector<F> { /* private fields */ }Expand description
The result of evaluating a vector of polynomials over all points in an interpolation domain.
This struct also remembers which rows have ever been filled with Self::fill_row. This is used in Self::recover, which can use the rows that are present to fill in the missing rows.
Implementations
Sourceimpl<F: FieldNTT> EvaluationVector<F>
impl<F: FieldNTT> EvaluationVector<F>
Sourcepub fn recover(self) -> PolynomialVector<F>
pub fn recover(self) -> PolynomialVector<F>
Attempt to recover the missing rows in this data.
Sourceimpl<F: Additive> EvaluationVector<F>
impl<F: Additive> EvaluationVector<F>
Sourceimpl<F> EvaluationVector<F>
impl<F> EvaluationVector<F>