Matrix

Struct Matrix 

pub struct Matrix<F> { /* private fields */ }
Represents a matrix of field elements, of arbitrary dimensions

This is in row major order, so consider processing elements in the same row first, for locality.

Implementations

Source

impl<F: Additive> Matrix<F>

pub fn init(rows: usize, cols: usize, data: impl Iterator<Item = F>) -> Self

Initialize a matrix, with dimensions, and data to pull from.

Any extra data is ignored, any data not supplied is treated as 0.

pub fn as_polynomials( &self, min_coefficients: usize, ) -> Option<PolynomialVector<F>>
where F: Clone,

Interpret the columns of this matrix as polynomials, with at least min_coefficients.

This will, in fact, produce a matrix padded to the next power of 2 of that number.

This will return None if min_coefficients < self.rows, which would mean discarding data, instead of padding it.

pub fn mul(&self, other: &Self) -> Self
where F: Clone + Ring,

Multiply this matrix by another.

This assumes that the number of columns in this matrix match the number of rows in the other matrix.

Source

impl<F> Matrix<F>

pub const fn rows(&self) -> usize

pub const fn cols(&self) -> usize

pub fn iter(&self) -> impl Iterator<Item = &[F]>

Iterate over the rows of this matrix.

Source

impl<F: Random> Matrix<F>

pub fn rand(rng: impl CryptoRngCore, rows: usize, cols: usize) -> Self
where F: Additive,

Create a random matrix with certain dimensions.