pub struct PolynomialVector<F> { /* private fields */ }Implementations
Sourceimpl<F: FieldNTT> PolynomialVector<F>
impl<F: FieldNTT> PolynomialVector<F>
Sourcepub fn evaluate(self) -> EvaluationVector<F>
pub fn evaluate(self) -> EvaluationVector<F>
Evaluate each polynomial in this vector over all points in an interpolation domain.
Sourceimpl<F> PolynomialVector<F>
impl<F> PolynomialVector<F>
Sourcepub fn coefficients_up_to(&self, n: usize) -> impl Iterator<Item = &[F]>
pub fn coefficients_up_to(&self, n: usize) -> impl Iterator<Item = &[F]>
Iterate over up to n rows of this vector.
For example, given polynomials:
a0 + a1 X + a2 X^2 + … b0 + b1 X + b2 X^2 + …
This will return:
a0 b0 a1 b1 …
up to n times.