pub struct VanishingPoints { /* private fields */ }Expand description
Used to keep track of the points at which a polynomial needs to vanish.
This takes care of subtle details like padding and bit ordering.
This struct is associated with a particular size, which is a power of two, and thus a particular root of unity.
Implementations
Sourceimpl VanishingPoints
impl VanishingPoints
Sourcepub fn new(lg_size: u32) -> Self
pub fn new(lg_size: u32) -> Self
This will have size 2^lg_size, and vanish everywhere.
Be aware that this means all points are initially marked as vanishing.
Sourcepub fn all_non_vanishing(lg_size: u32) -> Self
pub fn all_non_vanishing(lg_size: u32) -> Self
This will have size 2^lg_size, and vanish nowhere.
pub const fn lg_size(&self) -> u32
Sourcepub fn set_non_vanishing(&mut self, index: u64)
pub fn set_non_vanishing(&mut self, index: u64)
Set the root w^index to not vanish.
cf. set;
pub fn get(&self, index: u64) -> bool
pub fn count_non_vanishing(&self) -> u64