Structs
- Evaluation
Vector - The result of evaluating a vector of polynomials over all points in an interpolation domain.
- Matrix
- Represents a matrix of field elements, of arbitrary dimensions
- Polynomial
Vector - Vanishing
Points - Used to keep track of the points at which a polynomial needs to vanish.
Functions
- lagrange_
coefficients - Compute Lagrange coefficients for interpolating a polynomial at 0 from evaluations at roots of unity.