pub struct Matrix<F> { /* private fields */ }Expand description
Represents a matrix of field elements, of arbitrary dimensions
This is in row major order, so consider processing elements in the same row first, for locality.
Implementations
Sourceimpl<F: Additive> Matrix<F>
impl<F: Additive> Matrix<F>
Sourcepub fn init(rows: usize, cols: usize, data: impl Iterator<Item = F>) -> Self
pub fn init(rows: usize, cols: usize, data: impl Iterator<Item = F>) -> Self
Initialize a matrix, with dimensions, and data to pull from.
Any extra data is ignored, any data not supplied is treated as 0.
Sourcepub fn as_polynomials(
&self,
min_coefficients: usize,
) -> Option<PolynomialVector<F>>where
F: Clone,
pub fn as_polynomials(
&self,
min_coefficients: usize,
) -> Option<PolynomialVector<F>>where
F: Clone,
Interpret the columns of this matrix as polynomials, with at least min_coefficients.
This will, in fact, produce a matrix padded to the next power of 2 of that number.
This will return None if min_coefficients < self.rows, which would mean
discarding data, instead of padding it.